@@ -9,6 +9,7 @@ BACKEND = 'tensorflow'
 # BACKEND = 'mindspore'
 # BACKEND = 'paddle'
 # BACKEND = 'torch'
+# BACKEND = 'oneflow'
 
 # Check for backend.json files
 tl_backend_dir = os.path.expanduser('~')
@@ -76,5 +77,11 @@ elif BACKEND == 'torch':
     import torch
     BACKEND_VERSION = torch.__version__
     sys.stderr.write('Using PyTorch backend.\n')
+elif BACKEND == 'oneflow':
+    from .oneflow_nn import *
+    from .oneflow_backend import *
+    import oneflow
+    BACKEND_VERSION = oneflow.__version__
+    sys.stderr.write('Using OneFlow backend.\n')
 else:
     raise NotImplementedError("This backend is not supported")
