@@ -746,6 +746,14 @@ def reduce_min(input_tensor, axis=None, keepdims=False):
     return outputs
 
 
+class Pad2d(object):
+    def __init__(self, padding, mode='constant', value=0.0, data_format="NCHW", name=None):
+        pass
+
+    def __call__(self, x):
+        pass
+
+
 class Pad(Cell):
 
     def __init__(self, paddings, mode="REFLECT", constant_values=0):
@@ -1431,7 +1439,7 @@ def angle(x):
     return convert_to_tensor(np.angle(x_np))
 
 
-def argmax(x, axis=None, dtype='int64'):
+def argmax(x, axis=None, keepdim=False, dtype='int64'):
     return ms.numpy.argmax(x, axis=axis)
 
 
@@ -1889,4 +1897,80 @@ def logsoftmax(input, dim = None):
     if dim is None:
         dim = -1
     log_softmax = P.LogSoftmax(dim)
-    return log_softmax(input)
\ No newline at end of file
+    return log_softmax(input)
+
+def topk(input, k, dim=None, largest=True, sorted=True):
+    dims = len(input.shape) - 1
+    if dim is not None:
+        if dim < 0:
+            dim = len(input.shape) + dim
+        input = ms.numpy.swapaxes(input, dim, dims)
+    if not largest:
+        input = -input
+
+    values, indices = ms.ops.top_k(input, k=k, sorted=sorted)
+
+    if dim is not None:
+        values = ms.numpy.swapaxes(values, dim, dims)
+
+    if not largest:
+        values = -values
+
+    return (values, indices)
+
+def numel(input):
+
+    return ms.ops.size(input)
+
+
+def histogram(input, bins=100, min=0, max=0, name=None):
+    raise NotImplementedError
+
+
+def flatten(x, start_axis=0, stop_axis=-1, name=None):
+    raise NotImplementedError
+
+def interpolate(x,
+                size=None,
+                scale_factor=None,
+                mode='nearest',
+                align_corners=False,
+                align_mode=0,
+                data_format='NCHW',
+                name=None):
+    raise NotImplementedError
+
+
+def index_select(x, index, axis=0, name=None):
+    raise NotImplementedError
+
+
+def dot(x, y, name=None):
+    raise NotImplementedError
+
+
+class Swish(object):
+    def __init__(self):
+        pass
+
+    def __call__(self, x):
+        raise NotImplementedError
+
+def expand(x, shape):
+
+
+    raise NotImplementedError
+
+def unique(x, return_index=False, return_inverse=False, return_counts=False, axis=None, dtype='int64'):
+
+    raise NotImplementedError
+
+
+def flip(x, axis):
+
+    raise NotImplementedError
+
+
+def mv(x, vec):
+
+    raise NotImplementedError
