@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from collections.abc import Iterable
+
 from tensorlayerx.nn.core.common import _save_weights, _load_weights, \
     _save_standard_weights_dict, _load_standard_weights_dict
 from .utils import WithLoss, WithGradPD, WithGradMS, WithGradTF, TrainOneStepWithPD, \
@@ -12,6 +13,8 @@ from tensorlayerx.nn import Module
 import numpy as np
 import time
 
+from rich.progress import Progress, TextColumn, BarColumn, TimeElapsedColumn, TimeRemainingColumn
+
 if tlx.BACKEND == 'tensorflow':
     import tensorflow as tf
 if tlx.BACKEND == 'mindspore':
@@ -265,58 +268,75 @@ class Model:
         self, n_epoch, train_dataset, network, loss_fn, train_weights, optimizer, metrics, print_train_batch,
         print_freq, test_dataset
     ):
-        for epoch in range(n_epoch):
-            start_time = time.time()
+        with Progress(TextColumn("[progress.description]{task.description}"),
+                      BarColumn(),
+                      TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
+                      TimeRemainingColumn(),
+                      TimeElapsedColumn()) as progress:
 
-            train_loss, train_acc, n_iter = 0, 0, 0
-            for X_batch, y_batch in train_dataset:
-                network.set_train()
+            n_batch = len(train_dataset)
+            epoch_tqdm = progress.add_task(description="[red]Epoch progress 0/{}".format(n_epoch), total=n_epoch)
+            batch_tqdm = progress.add_task(description="[green]Batch progress 0/{}".format(n_batch), total=n_batch)
 
-                with tf.GradientTape() as tape:
-                    # compute outputs
-                    _logits = network(X_batch)
-                    # compute loss and update model
-                    _loss_ce = loss_fn(_logits, y_batch)
+            for epoch in range(n_epoch):
+                start_time = time.time()
 
-                grad = tape.gradient(_loss_ce, train_weights)
-                optimizer.apply_gradients(zip(grad, train_weights))
+                train_loss, train_acc, n_iter = 0, 0, 0
+                for batch, (X_batch, y_batch) in enumerate(train_dataset):
+                    network.set_train()
 
-                train_loss += _loss_ce
-                if metrics:
-                    metrics.update(_logits, y_batch)
-                    train_acc += metrics.result()
-                    metrics.reset()
-                else:
-                    train_acc += np.mean(np.equal(np.argmax(_logits, 1), y_batch))
-                n_iter += 1
+                    with tf.GradientTape() as tape:
+                        # compute outputs
+                        _logits = network(X_batch)
+                        # compute loss and update model
+                        _loss_ce = loss_fn(_logits, y_batch)
+
+                    grad = tape.gradient(_loss_ce, train_weights)
+                    optimizer.apply_gradients(zip(grad, train_weights))
+
+                    train_loss += _loss_ce
+                    if metrics:
+                        metrics.update(_logits, y_batch)
+                        train_acc += metrics.result()
+                        metrics.reset()
+                    else:
+                        train_acc += np.mean(np.equal(np.argmax(_logits, 1), y_batch))
+                    n_iter += 1
+
+                    if print_train_batch:
+                        print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
+                        print("   train loss: {}".format(train_loss / n_iter))
+                        print("   train acc:  {}".format(train_acc / n_iter))
+                    progress.advance(batch_tqdm, advance=1)
+                    progress.update(batch_tqdm, description="[green]Batch progress {}/{}".format(batch + 1, n_batch))
+
+                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
 
-                if print_train_batch:
                     print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
                     print("   train loss: {}".format(train_loss / n_iter))
                     print("   train acc:  {}".format(train_acc / n_iter))
 
-            if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
-                print("   train loss: {}".format(train_loss / n_iter))
-                print("   train acc:  {}".format(train_acc / n_iter))
+                if test_dataset:
+                    # use training and evaluation sets to evaluate the model every print_freq epoch
+                    if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
+                        network.set_eval()
+                        val_loss, val_acc, n_iter = 0, 0, 0
+                        for X_batch, y_batch in test_dataset:
+                            _logits = network(X_batch)  # is_train=False, disable dropout
+                            val_loss += loss_fn(_logits, y_batch)
+                            if metrics:
+                                metrics.update(_logits, y_batch)
+                                val_acc += metrics.result()
+                                metrics.reset()
+                            else:
+                                val_acc += np.mean(np.equal(np.argmax(_logits, 1), y_batch))
+                            n_iter += 1
+                        print("   val loss: {}".format(val_loss / n_iter))
+                        print("   val acc:  {}".format(val_acc / n_iter))
+                progress.update(epoch_tqdm, description="[red]Epoch progress {}/{}".format(epoch + 1, n_epoch))
+                progress.advance(epoch_tqdm, advance=1)
+                progress.reset(batch_tqdm)
 
-            if test_dataset:
-                # use training and evaluation sets to evaluate the model every print_freq epoch
-                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                    network.set_eval()
-                    val_loss, val_acc, n_iter = 0, 0, 0
-                    for X_batch, y_batch in test_dataset:
-                        _logits = network(X_batch)  # is_train=False, disable dropout
-                        val_loss += loss_fn(_logits, y_batch)
-                        if metrics:
-                            metrics.update(_logits, y_batch)
-                            val_acc += metrics.result()
-                            metrics.reset()
-                        else:
-                            val_acc += np.mean(np.equal(np.argmax(_logits, 1), y_batch))
-                        n_iter += 1
-                    print("   val loss: {}".format(val_loss / n_iter))
-                    print("   val acc:  {}".format(val_acc / n_iter))
 
     def ms_train(
         self, n_epoch, train_dataset, network, loss_fn, train_weights, optimizer, metrics, print_train_batch,
@@ -325,105 +345,141 @@ class Model:
         net_with_criterion = WithLoss(network, loss_fn)
         train_network = GradWrap(net_with_criterion, network.trainable_weights)
         train_network.set_train()
-        for epoch in range(n_epoch):
-            start_time = time.time()
-            train_loss, train_acc, n_iter = 0, 0, 0
-            for X_batch, y_batch in train_dataset:
-                output = network(X_batch)
-                loss_output = loss_fn(output, y_batch)
-                grads = train_network(X_batch, y_batch)
-                success = optimizer.apply_gradients(zip(grads, train_weights))
-                loss = loss_output.asnumpy()
-                train_loss += loss
-                if metrics:
-                    metrics.update(output, y_batch)
-                    train_acc += metrics.result()
-                    metrics.reset()
-                else:
-                    train_acc += np.mean((P.Equal()(P.Argmax(axis=1)(output), y_batch).asnumpy()))
-                n_iter += 1
 
-                if print_train_batch:
+        with Progress(TextColumn("[progress.description]{task.description}"),
+                      BarColumn(),
+                      TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
+                      TimeRemainingColumn(),
+                      TimeElapsedColumn()) as progress:
+
+            n_batch = len(train_dataset)
+            epoch_tqdm = progress.add_task(description="[red]Epoch progress 0/{}".format(n_epoch), total=n_epoch)
+            batch_tqdm = progress.add_task(description="[green]Batch progress 0/{}".format(n_batch), total=n_batch)
+
+            for epoch in range(n_epoch):
+                start_time = time.time()
+                train_loss, train_acc, n_iter = 0, 0, 0
+                for batch, (X_batch, y_batch) in enumerate(train_dataset):
+                    output = network(X_batch)
+                    loss_output = loss_fn(output, y_batch)
+                    grads = train_network(X_batch, y_batch)
+                    success = optimizer.apply_gradients(zip(grads, train_weights))
+                    loss = loss_output.asnumpy()
+                    train_loss += loss
+                    if metrics:
+                        metrics.update(output, y_batch)
+                        train_acc += metrics.result()
+                        metrics.reset()
+                    else:
+                        train_acc += np.mean((P.Equal()(P.Argmax(axis=1)(output), y_batch).asnumpy()))
+                    n_iter += 1
+
+                    if print_train_batch:
+                        print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
+                        print("   train loss: {}".format(train_loss / n_iter))
+                        print("   train acc:  {}".format(train_acc / n_iter))
+                    progress.advance(batch_tqdm, advance=1)
+                    progress.update(batch_tqdm, description="[green]Batch progress {}/{}".format(batch + 1, n_batch))
+
+                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
+
                     print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
                     print("   train loss: {}".format(train_loss / n_iter))
                     print("   train acc:  {}".format(train_acc / n_iter))
 
-            if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
-                print("   train loss: {}".format(train_loss / n_iter))
-                print("   train acc:  {}".format(train_acc / n_iter))
+                if test_dataset:
+                    # use training and evaluation sets to evaluate the model every print_freq epoch
+                    if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
+                        network.set_eval()
+                        val_loss, val_acc, n_iter = 0, 0, 0
+                        for X_batch, y_batch in test_dataset:
+                            _logits = network(X_batch)
+                            val_loss += loss_fn(_logits, y_batch)
+                            if metrics:
+                                metrics.update(_logits, y_batch)
+                                val_acc += metrics.result()
+                                metrics.reset()
+                            else:
+                                val_acc += np.mean((P.Equal()(P.Argmax(axis=1)(_logits), y_batch).asnumpy()))
+                            n_iter += 1
+                        print("   val loss: {}".format(val_loss / n_iter))
+                        print("   val acc:  {}".format(val_acc / n_iter))
+
+                progress.update(epoch_tqdm, description="[red]Epoch progress {}/{}".format(epoch + 1, n_epoch))
+                progress.advance(epoch_tqdm, advance=1)
+                progress.reset(batch_tqdm)
 
-            if test_dataset:
-                # use training and evaluation sets to evaluate the model every print_freq epoch
-                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                    network.set_eval()
-                    val_loss, val_acc, n_iter = 0, 0, 0
-                    for X_batch, y_batch in test_dataset:
-                        _logits = network(X_batch)
-                        val_loss += loss_fn(_logits, y_batch)
-                        if metrics:
-                            metrics.update(_logits, y_batch)
-                            val_acc += metrics.result()
-                            metrics.reset()
-                        else:
-                            val_acc += np.mean((P.Equal()(P.Argmax(axis=1)(_logits), y_batch).asnumpy()))
-                        n_iter += 1
-                    print("   val loss: {}".format(val_loss / n_iter))
-                    print("   val acc:  {}".format(val_acc / n_iter))
 
     def pd_train(
         self, n_epoch, train_dataset, network, loss_fn, train_weights, optimizer, metrics, print_train_batch,
         print_freq, test_dataset
     ):
-        for epoch in range(n_epoch):
-            start_time = time.time()
+        with Progress(TextColumn("[progress.description]{task.description}"),
+                      BarColumn(),
+                      TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
+                      TimeRemainingColumn(),
+                      TimeElapsedColumn()) as progress:
 
-            train_loss, train_acc, n_iter = 0, 0, 0
-            for X_batch, y_batch in train_dataset:
-                network.set_train()
+            n_batch = len(train_dataset)
+            epoch_tqdm = progress.add_task(description="[red]Epoch progress 0/{}".format(n_epoch), total=n_epoch)
+            batch_tqdm = progress.add_task(description="[green]Batch progress 0/{}".format(n_batch), total=n_batch)
 
-                output = network(X_batch)
-                loss = loss_fn(output, y_batch)
-                loss_ce = loss.numpy()
-                grads = optimizer.gradient(loss, train_weights)
-                optimizer.apply_gradients(zip(grads, train_weights))
+            for epoch in range(n_epoch):
+                start_time = time.time()
 
-                train_loss += loss_ce
-                if metrics:
-                    metrics.update(output, y_batch)
-                    train_acc += metrics.result()
-                    metrics.reset()
-                else:
-                    train_acc += pd.metric.accuracy(output, y_batch)
-                n_iter += 1
+                train_loss, train_acc, n_iter = 0, 0, 0
+                for batch, (X_batch, y_batch) in enumerate(train_dataset):
+                    network.set_train()
+
+                    output = network(X_batch)
+                    loss = loss_fn(output, y_batch)
+                    loss_ce = loss.numpy()
+                    grads = optimizer.gradient(loss, train_weights)
+                    optimizer.apply_gradients(zip(grads, train_weights))
+
+                    train_loss += loss_ce
+                    if metrics:
+                        metrics.update(output, y_batch)
+                        train_acc += metrics.result()
+                        metrics.reset()
+                    else:
+                        train_acc += pd.metric.accuracy(output, y_batch)
+                    n_iter += 1
+
+                    if print_train_batch:
+                        print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
+                        print("   train loss: {}".format(train_loss / n_iter))
+                        print("   train acc:  {}".format(train_acc / n_iter))
+                    progress.advance(batch_tqdm, advance=1)
+                    progress.update(batch_tqdm, description="[green]Batch progress {}/{}".format(batch + 1, n_batch))
+
+                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
 
-                if print_train_batch:
                     print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
                     print("   train loss: {}".format(train_loss / n_iter))
                     print("   train acc:  {}".format(train_acc / n_iter))
 
-            if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
-                print("   train loss: {}".format(train_loss / n_iter))
-                print("   train acc:  {}".format(train_acc / n_iter))
+                if test_dataset:
+                    # use training and evaluation sets to evaluate the model every print_freq epoch
+                    if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
+                        network.set_eval()
+                        val_loss, val_acc, n_iter = 0, 0, 0
+                        for X_batch, y_batch in test_dataset:
+                            _logits = network(X_batch)  # is_train=False, disable dropout
+                            val_loss += loss_fn(_logits, y_batch)
+                            if metrics:
+                                metrics.update(_logits, y_batch)
+                                val_acc += metrics.result()
+                                metrics.reset()
+                            else:
+                                val_acc += np.mean(np.equal(np.argmax(_logits, 1), y_batch))
+                            n_iter += 1
+                        print("   val loss: {}".format(val_loss / n_iter))
+                        print("   val acc:  {}".format(val_acc / n_iter))
+                progress.update(epoch_tqdm, description="[red]Epoch progress {}/{}".format(epoch + 1, n_epoch))
+                progress.advance(epoch_tqdm, advance=1)
+                progress.reset(batch_tqdm)
 
-            if test_dataset:
-                # use training and evaluation sets to evaluate the model every print_freq epoch
-                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                    network.set_eval()
-                    val_loss, val_acc, n_iter = 0, 0, 0
-                    for X_batch, y_batch in test_dataset:
-                        _logits = network(X_batch)  # is_train=False, disable dropout
-                        val_loss += loss_fn(_logits, y_batch)
-                        if metrics:
-                            metrics.update(_logits, y_batch)
-                            val_acc += metrics.result()
-                            metrics.reset()
-                        else:
-                            val_acc += np.mean(np.equal(np.argmax(_logits, 1), y_batch))
-                        n_iter += 1
-                    print("   val loss: {}".format(val_loss / n_iter))
-                    print("   val acc:  {}".format(val_acc / n_iter))
 
     def th_train(
         self, n_epoch, train_dataset, network, loss_fn, train_weights, optimizer, metrics, print_train_batch,
@@ -431,53 +487,70 @@ class Model:
     ):
         # device = torch.device('cuda:0' if torch.cuda.is_available() else 'cpu')
         # network = network.to(device)
-        for epoch in range(n_epoch):
-            start_time = time.time()
+        with Progress(TextColumn("[progress.description]{task.description}"),
+                      BarColumn(),
+                      TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
+                      TimeRemainingColumn(),
+                      TimeElapsedColumn()) as progress:
 
-            train_loss, train_acc, n_iter = 0, 0, 0
-            for X_batch, y_batch in train_dataset:
-                network.set_train()
-                output = network(X_batch)
-                loss = loss_fn(output, y_batch)
-                grads = optimizer.gradient(loss, train_weights)
-                optimizer.apply_gradients(zip(grads, train_weights))
+            n_batch = len(train_dataset)
+            epoch_tqdm = progress.add_task(description="[red]Epoch progress 0/{}".format(n_epoch), total=n_epoch)
+            batch_tqdm = progress.add_task(description="[green]Batch progress 0/{}".format(n_batch), total=n_batch)
 
-                train_loss += loss
-                if metrics:
-                    metrics.update(output, y_batch)
-                    train_acc += metrics.result()
-                    metrics.reset()
-                else:
-                    train_acc += (output.argmax(1) == y_batch).type(torch.float).mean().item()
-                n_iter += 1
+            for epoch in range(n_epoch):
+                start_time = time.time()
+
+                train_loss, train_acc, n_iter = 0, 0, 0
+                for batch, (X_batch, y_batch) in enumerate(train_dataset):
+                    network.set_train()
+                    output = network(X_batch)
+                    loss = loss_fn(output, y_batch)
+                    grads = optimizer.gradient(loss, train_weights)
+                    optimizer.apply_gradients(zip(grads, train_weights))
+
+                    train_loss += loss
+                    if metrics:
+                        metrics.update(output, y_batch)
+                        train_acc += metrics.result()
+                        metrics.reset()
+                    else:
+                        train_acc += (output.argmax(1) == y_batch).type(torch.float).mean().item()
+                    n_iter += 1
+
+                    if print_train_batch:
+                        print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
+                        print("   train loss: {}".format(train_loss / n_iter))
+                        print("   train acc:  {}".format(train_acc / n_iter))
+                    progress.advance(batch_tqdm, advance=1)
+                    progress.update(batch_tqdm, description="[green]Batch progress {}/{}".format(batch + 1, n_batch))
+
+                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
 
-                if print_train_batch:
                     print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
                     print("   train loss: {}".format(train_loss / n_iter))
                     print("   train acc:  {}".format(train_acc / n_iter))
 
-            if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                print("Epoch {} of {} took {}".format(epoch + 1, n_epoch, time.time() - start_time))
-                print("   train loss: {}".format(train_loss / n_iter))
-                print("   train acc:  {}".format(train_acc / n_iter))
+                if test_dataset:
+                    # use training and evaluation sets to evaluate the model every print_freq epoch
+                    if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
+                        network.set_eval()
+                        val_loss, val_acc, n_iter = 0, 0, 0
+                        for X_batch, y_batch in test_dataset:
+                            _logits = network(X_batch)  # is_train=False, disable dropout
+                            val_loss += loss_fn(_logits, y_batch)
+                            if metrics:
+                                metrics.update(_logits, y_batch)
+                                val_acc += metrics.result()
+                                metrics.reset()
+                            else:
+                                val_acc += (_logits.argmax(1) == y_batch).type(torch.float).mean().item()
+                            n_iter += 1
+                        print("   val loss: {}".format(val_loss / n_iter))
+                        print("   val acc:  {}".format(val_acc / n_iter))
+                progress.update(epoch_tqdm, description="[red]Epoch progress {}/{}".format(epoch + 1, n_epoch))
+                progress.advance(epoch_tqdm, advance=1)
+                progress.reset(batch_tqdm)
 
-            if test_dataset:
-                # use training and evaluation sets to evaluate the model every print_freq epoch
-                if epoch + 1 == 1 or (epoch + 1) % print_freq == 0:
-                    network.set_eval()
-                    val_loss, val_acc, n_iter = 0, 0, 0
-                    for X_batch, y_batch in test_dataset:
-                        _logits = network(X_batch)  # is_train=False, disable dropout
-                        val_loss += loss_fn(_logits, y_batch)
-                        if metrics:
-                            metrics.update(_logits, y_batch)
-                            val_acc += metrics.result()
-                            metrics.reset()
-                        else:
-                            val_acc += (_logits.argmax(1) == y_batch).type(torch.float).mean().item()
-                        n_iter += 1
-                    print("   val loss: {}".format(val_loss / n_iter))
-                    print("   val acc:  {}".format(val_acc / n_iter))
 
 
 class WithGrad(object):
@@ -602,14 +675,17 @@ class TrainOneStepWithGradientClipping(object):
             raise Exception("This method must input the gradient clipping function, eg tlx.ops.ClipByGlobalNorm(0.1).")
 
         if tlx.BACKEND == 'tensorflow':
-            self.net_weith_train = TrainOneStepWithGradientClippingTF(net_with_loss, optimizer, train_weights, gradient_clipping)
+            self.net_weith_train = TrainOneStepWithGradientClippingTF(
+                net_with_loss, optimizer, train_weights, gradient_clipping)
         elif tlx.BACKEND == 'paddle':
-            self.net_weith_train = TrainOneStepWithGradientClippingPD(net_with_loss, optimizer, train_weights, gradient_clipping)
+            self.net_weith_train = TrainOneStepWithGradientClippingPD(
+                net_with_loss, optimizer, train_weights, gradient_clipping)
         elif tlx.BACKEND == 'torch':
-            self.net_weith_train = TrainOneStepWithGradientClippingTH(net_with_loss, optimizer, train_weights, gradient_clipping)
+            self.net_weith_train = TrainOneStepWithGradientClippingTH(
+                net_with_loss, optimizer, train_weights, gradient_clipping)
         else:
             raise NotImplementedError("This backend is not supported")
 
     def __call__(self, data, label):
         loss = self.net_weith_train(data, label)
-        return loss
\ No newline at end of file
+        return loss
