@@ -23,7 +23,8 @@ _act_dict = {
     "softplus": tlx.ops.Softplus,
     "tanh": tlx.ops.Tanh,
     "sigmoid": tlx.ops.Sigmoid,
-    "softmax": tlx.ops.Softmax
+    "softmax": tlx.ops.Softmax,
+    "swish": tlx.ops.Swish
 }
 
 _initializers_dict = {
@@ -560,7 +561,7 @@ class ModuleNode(object):
 
     Parameters
     ----------
-    layer : tl.layers.Layer
+    layer : tlx.layers.Layer
         A tl layer that wants to create a node.
     node_index : int
         Index of this node in layer._nodes.
