@@ -270,8 +270,8 @@ class Module(Layer):
     def save_standard_weights(self, file_path):
         _save_standard_weights_dict(self, file_path)
 
-    def load_standard_weights(self, file_path, skip=False, reshape=False, format='npz_dict'):
-        _load_standard_weights_dict(self, file_path, skip, reshape, format)
+    def load_standard_weights(self, file_path, weights_from, weights_to, skip=False):
+        _load_standard_weights_dict(self, file_path, skip=skip, weights_from=weights_from, weights_to=weights_to)
 
     def str_to_init(self, initializer):
         return str2init(initializer)
@@ -300,6 +300,10 @@ class Module(Layer):
             raise TypeError("Child layer type is incorrect.")
         self._sub_layers[child_name] = child
 
+    def set_build_graph(self):
+
+        raise NotImplementedError
+
     def build_graph(self, *inputs, **kwargs):
         # Add nodes only when the composition is needed.
         # for layer in self.sublayers():
@@ -730,7 +734,6 @@ class ParameterDict(Module):
                         "ParameterDict update sequence element "
                         "#" + str(j) + " should be Iterable; is" + type(p).__name__
                     )
-                print(p)
                 if not len(p) == 2:
                     raise ValueError(
                         "ParameterDict update sequence element "
