@@ -221,7 +221,7 @@ class Module(object):
 
         _save_standard_weights_dict(self, file_path)
 
-    def load_standard_weights(self, file_path, skip=False, reshape=False, format='npz_dict'):
+    def load_standard_weights(self, file_path, weights_from, weights_to, skip=False):
         """
 
         Parameters
@@ -231,14 +231,13 @@ class Module(object):
         skip : boolean
             If 'skip' == True, loaded layer whose name is not found in 'layers' will be skipped. If 'skip' is False,
             error will be raised when mismatch is found. Default False.
-        reshape : boolean
-            This parameter needs to be set to True when importing parameters from tensorflow training to paddle/mindspore/pytorch,
-            and similarly when importing parameters from paddle/mindspore/pytorch training to tensorflow.
-            This parameter does not need to be set between paddle/mindspore/pytorch.
-
+        weights_from : string
+            The weights file is saved by which framework training. It has to be one of tensorflow,mindspore,paddle or torch.
+        weights_to : string
+            Which framework the weights file imports.It has to be one of tensorflow,mindspore,paddle or torch.
         """
 
-        _load_standard_weights_dict(self, file_path, skip, reshape, format)
+        _load_standard_weights_dict(self, file_path, skip=skip, weights_from=weights_from, weights_to=weights_to)
 
     def _set_mode_for_layers(self, is_train):
         """Set all layers of this network to a given mode.
@@ -640,11 +639,16 @@ class Module(object):
     def check_param(self, param, dim='2d'):
         return check_parameter(param, dim)
 
-    def build_graph(self, *inputs, **kwargs):
-        # Add nodes only when the composition is needed.
+    def set_build_graph(self):
         for layer_name, layer in self._layers.items():
             if isinstance(layer, Module):
+                if len(layer._layers) > 1:
+                    layer.set_build_graph()
                 layer._build_graph = True
+
+    def build_graph(self, *inputs, **kwargs):
+        # Add nodes only when the composition is needed.
+        self.set_build_graph()
         self.set_eval()
 
         outputs = self.forward(*inputs, **kwargs)
@@ -775,31 +779,26 @@ class Sequential(Module):
 
     def forward(self, input_data):
         for layer in self.layer_list:
-            inputs = input_data
             input_data = layer(input_data)
-            outputs = input_data
-            if not self._nodes_fixed and self._build_graph:
-                self._add_seq_node(inputs, outputs, layer)
-        self._nodes_fixed = True
         return input_data
-
-    def _add_seq_node(self, input_tensors, output_tensors, layer):
-        inputs_list = tolist(input_tensors)
-        outputs_list = tolist(output_tensors)
-        if layer.__class__.__name__ in tlx.layers.inputs.__all__:
-            in_nodes = []
-            in_tensor_idxes = [0]
-        else:
-            in_nodes = [tensor._info[0] for tensor in inputs_list]
-            in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
-        node_index = len(_global_layer_node)
-
-        new_node = ModuleNode(
-            layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
-        )
-        _global_layer_node.append(new_node)
-        for idx, tensor in enumerate(outputs_list):
-            tensor._info = (new_node, idx)
+    #
+    # def _add_seq_node(self, input_tensors, output_tensors, layer):
+    #     inputs_list = tolist(input_tensors)
+    #     outputs_list = tolist(output_tensors)
+    #     if layer.__class__.__name__ in tlx.layers.inputs.__all__:
+    #         in_nodes = []
+    #         in_tensor_idxes = [0]
+    #     else:
+    #         in_nodes = [tensor._info[0] for tensor in inputs_list]
+    #         in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
+    #     node_index = len(_global_layer_node)
+    #
+    #     new_node = ModuleNode(
+    #         layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
+    #     )
+    #     _global_layer_node.append(new_node)
+    #     for idx, tensor in enumerate(outputs_list):
+    #         tensor._info = (new_node, idx)
 
 
 class ModuleList(Module):
