@@ -7,7 +7,7 @@ from tensorlayerx.nn.core import Module
 
 __all__ = [
     'ELU', 'PRelu', 'PRelu6', 'PTRelu6', 'ReLU', 'ReLU6', 'Softplus', 'LeakyReLU', 'LeakyReLU6', 'LeakyTwiceRelu6',
-    'Ramp', 'Swish', 'HardTanh', 'Mish', 'Tanh', 'Sigmoid', 'Softmax', 'LogSoftmax'
+    'Ramp', 'Swish', 'HardTanh', 'Mish', 'Tanh', 'Sigmoid', 'Softmax', 'LogSoftmax', 'HardSigmoid', 'Hardswish'
 ]
 
 
@@ -46,9 +46,10 @@ class PRelu(Module):
 
         super(PRelu, self).__init__(name)
         self.num_parameters = num_parameters
-        self.init = init
+        self.init = tlx.initializers.constant(value=init)
         self.data_format = data_format
-
+        self.build()
+        self._built = True
         logging.info("PRelu %s: num_parameters: %s" % (self.name, self.num_parameters))
 
     def __repr__(self):
@@ -59,29 +60,13 @@ class PRelu(Module):
         s += ')'
         return s.format(classname=self.__class__.__name__, **self.__dict__)
 
-    def build(self, inputs_shape):
-        dim = len(inputs_shape)
-        if self.data_format == 'channels_last':
-            w_shape = (self.num_parameters, )
-        elif self.data_format == 'channels_first':
-            if dim == 4:
-                w_shape = (1, self.num_parameters, 1, 1)
-            elif dim == 3:
-                w_shape = (1, self.num_parameters, 1)
-            elif dim == 5:
-                w_shape = (1, self.num_parameters, 1, 1, 1)
-            elif dim < 3:
-                w_shape = (self.num_parameters, )
+    def build(self):
 
-        self.alpha = self._get_weights("alpha", shape=w_shape, init=tlx.initializers.constant(value=self.init))
+        w_shape = (self.num_parameters, )
+        self.alpha = self._get_weights("alpha", shape=w_shape, init=self.init)
         self.prelu = tlx.ops.PReLU(data_format = self.data_format)
 
     def forward(self, inputs):
-        if self._forward_state == False:
-            if self._built == False:
-                self.build(tlx.get_tensor_shape(inputs))
-                self._built = True
-            self._forward_state = True
 
         output = self.prelu(inputs, self.alpha)
 
@@ -827,11 +812,11 @@ class Swish(Module):
 
     def __init__(self):
         super(Swish, self).__init__()
-        self.sigmoid = tlx.ops.Sigmoid()
+        # self.sigmoid = tlx.ops.Sigmoid()
         self._built = True
 
     def forward(self, x):
-        outputs = self.sigmoid(x) * x
+        outputs = tlx.ops.swish(x)
 
         if not self._nodes_fixed and self._build_graph:
             self._add_node(x, outputs)
@@ -879,25 +864,25 @@ class HardTanh(Module):
 class Mish(Module):
     r"""Applies the Mish function, element-wise. Mish: A Self Regularized Non-Monotonic Neural Activation Function.
 
-        .. math::
+    .. math::
         \text{Mish}(x) = x * \text{Tanh}(\text{Softplus}(x))
 
-        Reference: [Mish: A Self Regularized Non-Monotonic Neural Activation Function .Diganta Misra, 2019]<https://arxiv.org/abs/1908.08681>
+    Reference: [Mish: A Self Regularized Non-Monotonic Neural Activation Function .Diganta Misra, 2019]<https://arxiv.org/abs/1908.08681>
 
-        Parameters
-        ----------
-        x : Tensor
-            input.
+    Parameters
+    ----------
+    x : Tensor
+        input.
 
-        Examples
-        --------
-        >>> net = tlx.nn.Input([10, 200])
-        >>> net = tlx.nn.Mish()(net)
+    Examples
+    --------
+    >>> net = tlx.nn.Input([10, 200])
+    >>> net = tlx.nn.Mish()(net)
 
-        Returns
-        -------
-        Tensor
-            A ``Tensor`` in the same type as ``x``.
+    Returns
+    -------
+    Tensor
+        A ``Tensor`` in the same type as ``x``.
 
     """
 
@@ -918,26 +903,26 @@ class Mish(Module):
 class LogSoftmax(Module):
     r"""Applies a softmax followed by a logarithm.
 
-        .. math::
+    .. math::
         \text{LogSoftmax}(x_{i}) = \log\left(\frac{\exp(x_i) }{ \sum_j \exp(x_j)} \right)
 
 
-        Parameters
-        ----------
-        x : Tensor
-            input.
-        dim : int
-            A dimension along which LogSoftmax will be computed.
+    Parameters
+    ----------
+    x : Tensor
+        input.
+    dim : int
+        A dimension along which LogSoftmax will be computed.
 
-        Examples
-        --------
-        >>> net = tlx.nn.Input([10, 200])
-        >>> net = tlx.nn.LogSoftmax()(net)
+    Examples
+    --------
+    >>> net = tlx.nn.Input([10, 200])
+    >>> net = tlx.nn.LogSoftmax()(net)
 
-        Returns
-        -------
-        Tensor
-            A ``Tensor`` in the same type as ``x``.
+    Returns
+    -------
+    Tensor
+        A ``Tensor`` in the same type as ``x``.
 
     """
 
@@ -953,3 +938,85 @@ class LogSoftmax(Module):
             self._add_node(x, outputs)
             self._nodes_fixed = True
         return outputs
+
+class HardSigmoid(Module):
+    r"""Applies the element-wise function:
+
+    .. math::
+        \text{Hardsigmoid}(x) = \begin{cases}
+            0 & \text{if~} x \le -3, \\
+            1 & \text{if~} x \ge +3, \\
+            x / 6 + 1 / 2 & \text{otherwise}
+        \end{cases}
+
+
+    Parameters
+    ----------
+    x : Tensor
+        input.
+
+    Examples
+    --------
+    >>> net = tlx.nn.Input([10, 200])
+    >>> net = tlx.nn.HardSigmoid()(net)
+
+    Returns
+    -------
+    Tensor
+        A ``Tensor`` in the same type as ``x``.
+
+    """
+
+    def __init__(self):
+        super(HardSigmoid, self).__init__()
+        self._built = True
+
+    def forward(self, x):
+        outputs = tlx.ops.hardsigmoid(x)
+
+        if not self._nodes_fixed and self._build_graph:
+            self._add_node(x, outputs)
+            self._nodes_fixed = True
+        return outputs
+
+class Hardswish(Module):
+    r"""Applies the hardswish function, element-wise, as described in the paper:
+
+    `Searching for MobileNetV3`_.
+
+    .. math::
+        \text{Hardswish}(x) = \begin{cases}
+            0 & \text{if~} x \le -3, \\
+            x & \text{if~} x \ge +3, \\
+            x \cdot (x + 3) /6 & \text{otherwise}
+        \end{cases}
+
+
+    Parameters
+    ----------
+    x : Tensor
+        input.
+
+    Examples
+    --------
+    >>> net = tlx.nn.Input([10, 200])
+    >>> net = tlx.nn.Hardswish()(net)
+
+    Returns
+    -------
+    Tensor
+        A ``Tensor`` in the same type as ``x``.
+
+    """
+
+    def __init__(self):
+        super(Hardswish, self).__init__()
+        self._built = True
+
+    def forward(self, x):
+        outputs = tlx.ops.hardswish(x)
+
+        if not self._nodes_fixed and self._build_graph:
+            self._add_node(x, outputs)
+            self._nodes_fixed = True
+        return outputs
\ No newline at end of file
