@@ -1,13 +1,5 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
-"""
-TensorLayer provides rich layer implementations trailed for
-various benchmarks and domain-specific problems. In addition, we also
-support transparent access to native TensorFlow parameters.
-For example, we provide not only layers for local response normalization, but also
-layers that allow user to apply ``tf.ops.lrn`` on ``network.outputs``.
-More functions can be found in `TensorFlow API <https://www.tensorflow.org/versions/master/api_docs/index.html>`__.
-"""
 
 # from .amsgrad import AMSGrad
 
@@ -24,3 +16,6 @@ from .load_optimizers_backend import Momentum
 from .load_optimizers_backend import Lamb
 from .load_optimizers_backend import LARS
 from tensorlayerx.optimizers import lr
+
+__all__ = ['Adadelta', 'Adagrad', 'Adam', 'Adamax', 'Ftrl', 'Nadam', 'RMSprop', 'SGD', 'Momentum', 'Lamb', 'LARS']
+
